("GNU" "GNU")
("LaTeX" "LaTeX")
("TeX" "TeX")
("a modifier" "modyfikator a")
("abbreviation" "skrt")
("about" "o mnie")
("about menu" "o menu")
("above" "ponad")
("abstract" "streszczenie")
("accent" "akcent")
("accept" "zaakceptuj")
("accept all scripts" "akceptuj skrypty")
("accept no scripts" "adnych skryptw")
("accept script" "akceptuj skrypt")
("acknowledgment" "podzikowanie")
("acronym" "akronim")
("action" "operacja")
("activate" "aktywacja")
("acute" "acute")
("add switch after" "wstaw przecznik po")
("add switch before" "wstaw przecznik przed")
("address" "adres")
("address block" "blok adresu")
("advanced" "trudniejsze")
("advanced layout features" "zaawansowany ukad")
("after" "po")
("albanian" "albaski")
("algorithm" "algorytm")
("align cell to the bottom" "wyrwnaj komrk do dou")
("align cell to the left" "wyrwnaj komrk do lewej")
("align cell to the right" "wyrwnaj komrk do prawej")
("align cell to the top" "wyrwnaj komrk do gry")
("align table at base of left column" "wyrwnaj tablic do bazy lewej kolumny")
("align table at base of middle column" "wyrwnaj tablic do bazy rodkowej kolumny")
("align table at base of origin column" "wyrwnaj tablic do bazy kolumny")
("align table at base of right column" "wyrwnaj tablic do bazy prawej kolumny")
("align table at fraction bar height" "wyrwnaj tablic do czci wysokoci")
("align table at the base of bottom row" "wyrwnaj tablic do bazy dolnego rzdu")
("align table at the base of middle row" "wyrwnaj tablic to bazy rodkowego rzdu")
("align table at the base of origin row" "wyrwnaj tablic do bazy rzdu")
("align table at the base of top row" "wyrwnaj tablic do bazy grnego rzdu")
("align table at the bottom" "wyrwnaj tablic do dou")
("align table at the center" "wyrwnaj tablic do rodka")
("align table at the horizontal center" "wyrwnaj tablic do rodka poziomo")
("align table at the left" "wyrwnaj tablic do lewej")
("align table at the top" "wyrwnaj tablic do gry")
("align table to the right" "wyrwnaj tablic do prawej")
("align text to the left" "dosu tekst w lewo")
("align text to the right" "dosu tekst w prawo")
("aligned" "dostawiony")
("alignment" "wyrwnanie")
("all" "wszystko")
("allow" "dopu")
("allowed extension" "dopuszczalne rozszerzenie")
("allowed reduction" "dopuszczalna redukcja")
("alpha release" "wydanie alpha")
("alt key" "klawisz alt")
("and" "i")
("appendix" "dodatek")
("apply" "zastosuj")
("april" "kwiecie")
("arab" "arabski")
("archaic" "archaiczny")
("architecture" "architektura")
("argument" "argument")
("arithmetic" "arytmetyczny")
("armenian" "armeski")
("arrow" "strzaka")
("arrows" "strzaki")
("article" "artyku")
("as on paper" "jak na papierze")
("assign" "przypisz")
("at fraction bar height" "do wysokoci linii frakcji")
("at the baseline" "do lini bazowej")
("at the bottom" "do dou")
("at the left" "do lewej")
("at the middle" "do rodka")
("at the right" "do prawej")
("at the top" "do gry")
("attach" "docz")
("attach buffer to which project" "docz bufor do projektu")
("august" "sierpie")
("author" "autor")
("authorize" "autoryzuj")
("automatic" "automatyczny")
("automatic quotes" "automatyczne cudzysowy")
("automatically close brackets" "automatyczne zamykanie nawiasw")
("automatically generated content" "spis generowany automatycznie")
("axiom" "aksjomat")
("background" "to")
("background color" "kolor ta")
("backward replace" "zamieniaj w ty")
("backward search" "szukaj w ty")
("bad data format" "zy format danych")
("bar" "kreska")
("bard" "bard")
("base level" "poziom bazy")
("bashkirian" "bashkirian")
("basic" "podstawowy")
("basic communication using pipes" "podstawowa komunikacja za pomoc potokw")
("basic data types" "podstawowe typy danych")
("basic types" "gwne typy")
("be useful" "uytki")
("become a TeXmacs developer" "zosta deweloperem TeXmacs'a")
("before" "przed")
("begin" "pocztek")
("below" "poniej")
("beta release" "wydanie beta")
("bibliography" "bibliografia")
("bibliography file" "plik z bibliografi")
("bibliography style" "styl bibliografii")
("big" "wielki")
("big figure" "duy obrazek")
("big operator" "duy operator")
("big skip" "duy odstp")
("big table" "dua tablica")
("binary operation" "operacja binarna")
("binary relation" "relacja binarna")
("black" "czarny")
("blackboard bold" "blackboard bold")
("blackboard math" "blackboard math")
("blackletter" "blackletter")
("blue" "niebieski")
("body" "zawarto")
("bold" "tusty")
("book" "ksika")
("border" "obramowanie")
("both" "oba")
("bottom" "na koniec")
("bottom border" "dolna ramka")
("bottom margin" "dolny margines")
("bottom padding" "dolne wypenienie")
("branch" "zakres")
("break" "zakocz")
("breaking" "przerwanie")
("breve" "breve")
("british" "brytyjski")
("broken white" "zestarzay biay")
("brown" "brzowy")
("browse" "przegldaj")
("browse web" "przegldaj web")
("browser" "przegld")
("buffer" "bufor")
("bulgarian" "bugarski")
("bullet" "kropka")
("bullets" "kropki")
("by" "autor")
("by typing" "przez wpisanie")
("bytes free" "bajtw wolnych")
("bytes used" "bajtw zajtych")
("calligraphic" "kaligraficzny")
("cancel" "anuluj")
("caps-lock key" "klawisz caps-lock")
("case" "wybr")
("cc" "cc")
("cell" "komrka")
("cell background color" "kolor ta komrki")
("cell border" "ramka komrki")
("cell height" "wysoko komrki")
("cell operation mode" "forma operacji komrkowych")
("cell width" "wysoko komrki")
("center" "na rodek")
("center text" "centruj tekst")
("centered" "wyrodkowany")
("centered block" "blok wyrodkowany")
("centered tabular" "centrowane tabulowanie")
("change border of cell" "zmie obramowanie komrki")
("change cell operation mode" "zmie sposb operacji komrkowych")
("change log" "opis zmian")
("changes" "zmiany")
("chapter" "rozdzia")
("check" "haczyk")
("check text for spelling errors" "sprawd pisowni tekstu")
("chinese" "chiski")
("choice" "wybr")
("citation" "cytat")
("cite" "cytat")
("class" "klasa")
("clear" "wyczy")
("clear selection" "odznaczenie")
("clipped" "uchwycony")
("clipped and magnified" "uchwycony i powikszony")
("clipped and resized" "uchwycony i przeskalowany")
("clone" "klonuj")
("clone window" "klonuj okno")
("close" "zamknij")
("close TeXmacs" "zamknij TeXmacs")
("close buffer" "zamknij bufor")
("close session" "zamknij sesj")
("close window" "zamknij okno")
("closing" "zamkoczenie")
("code" "kod")
("color" "kolor")
("column" "kolumna")
("column contains glued items" "kolumna zawiera elementy sklejone")
("compact" "kompaktowy")
("compatibility with other formats" "zgodno z innymi formatami")
("compile article" "kompiluj artyku")
("compile book" "kompiluj ksik")
("compile buffer" "kompiluj bufor")
("compile project" "kompiluj projekt")
("completion" "uzupenianie")
("complex" "zoone")
("concrete" "concrete")
("condensed" "zwarty")
("condition" "warunek")
("configuration" "konfiguracja")
("content" "zawarto")
("content tag" "znacznik zawartoci")
("context dependent icons" "ikony kontekstowe")
("continuation of" "kontynuacja")
("convention" "konwencja")
("converters to other data formats" "konwertery do innych formatw danych")
("copy" "kopiuj")
("copy text" "kopiuj tekst")
("copy to" "kopiuj do")
("copying" "kopiowanie")
("corollary" "wniosek")
("correct text" "poprawny tekst")
("cursors" "kursor")
("custom tab" "wasny tab")
("customizing TeXmacs" "dostosuj TeXmacs'a")
("customizing the TeXmacs styles" "dostosuj style TeXmacs'a")
("custum tab" "wasny tab")
("cut" "wytnij")
("cut text" "wytnij tekst")
("cut to" "wytnij to")
("cypriot" "cypriot")
("cyrillic" "cyrylica")
("cyrillic input method" "metoda wpisu cyrylicy")
("cyrillic italic right" "cyrylica-kursywa")
("czech" "czeski")
("dancers" "dancers")
("danish" "duski")
("dark grey" "ciemno-szary")
("dash" "kreska")
("dashes" "kreski")
("data conversion" "konwersja danych")
("data format" "format danych")
("date" "data")
("deactivate" "wycz")
("deactivate table" "wycz tablic")
("december" "grudzie")
("decorate atoms" "dekorowane atomy")
("default" "domylne")
("default padding" "podstawowe wypenienie")
("definition" "definicja")
("delete" "skasuj")
("delete column" "kasuj kolumn")
("delete row" "kasuj rzd")
("denominator" "mianownik")
("description" "opis")
("destination" "przeznaczenie")
("detach" "odcz")
("determinant" "wyznacznik")
("devangari" "devangari")
("developers guide" "przwodnik deweroperw")
("directory" "katalog")
("disable first indentation" "zakocz pierwsze wcicie")
("disable first indentation after" "zakocz pierwsze wcicie po")
("disable first indentation before" "zakocz pierwsze wcicie przed")
("disable indentation" "zakocz wcinanie")
("disable indentation after" "zakocz wcinanie po")
("disable indentation before" "zakocz wcinanie przed")
("disallow" "zabro")
("distribute unused space" "rozmie nieuyteczne spacje")
("div" "dziel")
("do not remap" "nie zmieniaj mapowania")
("document" "dokument")
("document format" "format dokumentu")
("document style" "styl dokumentu")
("document styles" "styl dokumentu")
("documentation" "dokumentacji")
("documents are trees" "dokumenty s drzewami")
("dot" "kropka")
("dots" "wykropkowanie")
("double stroke" "double stroke")
("down" "w d")
("dpi" "dpi")
("duplicate" "duplikat")
("dutch" "holenderski")
("dynamic libraries" "biblioteki dynamiczne")
("edit" "edytuj")
("editing tools" "narzdzia edycji")
("email" "email")
("emphasize" "wytu")
("emphasize text" "wytu tekst")
("empty box" "pusta ramka")
("enable first indentation" "wcz pierwsze wcicie")
("enable first indentation after" "wcz pierwsze wcicie po")
("enable first indentation before" "wcz pierwsze wcicie przed")
("enable indentation" "wcz wcinanie")
("enable indentation after" "wcz wcinanie po")
("enable indentation before" "wcz wcinanie przed")
("encl" "encl")
("end" "koniec")
("english" "angielski")
("enter a title" "podaj tytu")
("enumerate" "wyliczenie")
("enumerate|Alpha" "wyliczenie|Alfa")
("enumerate|Roman" "wyliczenie|Rzymskie")
("enumerate|alpha" "wyliczenie|alfa")
("enumerate|roman" "wyliczenie|rzymskie")
("env" "rod")
("environment" "rodowisko")
("epilogue" "epilog")
("equal" "rwny")
("equation" "rwnanie")
("equations" "rwnania")
("equivalent for" "rwnowany")
("error" "bd")
("esperanto" "esperanto")
("etruscan" "etruski")
("evaluate" "ewaluacjia")
("evaluate scheme expression" "interpertuj wyraenie scheme")
("even page footer" "parzysta stopka")
("even page header" "parzysty nagwek")
("even page margin" "parzyst marginesy strony")
("even page text" "parzysty tekst strony")
("exact horizontal" "dokadnie w poziomie")
("exact mode" "tryb dokadny")
("exam" "exam")
("example" "przykad")
("exclusive" "exclusive")
("exclusive or" "exclusive or")
("executable" "executable")
("execute" "wykonaj")
("execute a TeXmacs command" "wykonaj komend TeXmacsa")
("execute system command" "wykonaj komend systemow")
("executive" "executive")
("exercise" "wiczenie")
("expand" "rozszerz")
("explained" "wytumacz")
("export" "eksportuj")
("export as" "eksportuj jako")
("extend or normal" "rozszerz lub normalizuj")
("extern " "zewntrzne")
("extra" "dodatki")
("extract format" "otrzymany format")
("family" "rodzina")
("february" "luty")
("figure" "rysunek")
("file" "plik")
("file name" "nazwa pliku")
("file not found" "pliku nie znaleziono")
("find next match" "znajd nastpne dopasowanie")
("find text" "znajd tekst")
("finnish" "fiski")
("first contact" "pierwszy kontakt")
("first indentation" "pierwsze wcicie")
("first item" "pierwsze wyszczeglnienie")
("first page" "pierwsza strona")
("first start" "pierwszy start")
("flat" "paski")
("flexibility" "elastyczno")
("flexibility factor for vertical spacing" "elastyczny czynnik odstpw w pionie")
("floating figure" "pynny obrazek")
("floating object" "pynny obiekt")
("floating table" "pynna tablica")
("fold" "zszycie")
("folded" "zszyty")
("font" "czcionka")
("font base size" "rozmiar czcionki podstawowej")
("font dpi" "dpi czcionki")
("font family" "czcionka z rodziny")
("font name" "nazwa czcionki")
("font series" "czcionka seria")
("font shape" "czcionka ksztat")
("font size" "rozmiar czcionki")
("font type" "rodzaj czcionk")
("font variant" "wariant czcionki")
("fonts" "czcionki")
("footer" "stopka")
("footnote" "przypis")
("for" "dla")
("foreground" "przd")
("foreign" "obcy")
("format" "format")
("formatted date" "sformatowana data")
("formula" "wzr")
("formula style" "styl rwnania")
("forward replace" "zamieniaj w przd")
("forward search" "szukaj w przd")
("fraction" "uamek")
("french" "francuski")
("full manuals" "peny podrcznik")
("function" "funkcja")
("further customization" "dalsze dostosowanie")
("future changes" "planowane zmiany")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs nie pociga za sob adnej gwarancji prawnej")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs jest chroniony przez GNU general public license")
("general architecture of TeXmacs" "oglna architektura TeXmacs'a")
("general negation" "oglna negacja")
("generating font file" "generowanie pliku czcionek")
("generic" "oglny")
("georgian" "georgian")
("german" "niemiecki")
("getting started" "uruchamianie")
("glossary" "sownik")
("glossary entry" "haso sownika")
("glue" "sklej")
("glue decorations" "przyklej dekoracje")
("go" "id")
("gothic" "gotycki")
("graphical interface" "interfejs graficzny")
("grave" "grave")
("greater" "wikszy")
("greater or equal" "wikszy lub rwny")
("greek" "grecki")
("greek letter" "litera grecka")
("green" "zielony")
("grey" "szary")
("group" "grupa")
("h modifier" "modyfikator h")
("happy typing" "wpisywanie")
("has been aborted" "zostao odrzucone")
("has completed its task" "zakoczy zadanie")
("hat" "daszek")
("header" "nagwek")
("header and footer" "nagwek i stopka")
("hebrew" "hebrajski")
("height" "wysoko")
("height is exactly the specified height" "wysoko jest podana dokadnie")
("height is maximum of specified height and box height" "wysoko jest maksimum z podanej i wysokoci pudeka")
("height is minimum of specified height and box height" "wysoko jest minimum z podanej i wysokoci pudeka")
("height magnification" "zwikszenie w pionie")
("help" "pomoc")
("help me" "pom mi")
("help us" "pom nam")
("here" "tutaj")
("home" "home")
("horizontal" "poziomo")
("horizontal cell alignment" "wyrwnanie poziome komrki")
("horizontal ink separation" "poziomy odstp")
("horizontal part" "cz pozioma")
("horizontal position" "pooenie pionowe")
("horizontal space" "odstp poziomy")
("horizontal table alignment" "wyrwnanie poziome tablicy")
("horizontally align cell to the base" "wyrwnaj poziomo komrk do bazy")
("horizontally center the cell" "wycentruj poziomo komrk")
("how much longer may pages become" "o ile strona moe by dusza")
("how much shorter may pages become" "o ile strona moe by krtsza")
("huge" "ogromny")
("hungarian" "wgierski")
("hyperlink" "hiperlink")
("hyphenation" "podzia wyrazw")
("icelandic" "icelandic")
("if" "jeli")
("image" "obrazek")
("image links" "linki do obrazkw")
("implementation" "implementacja")
("import" "importuj")
("improving the current implementation" "popraw biec implementacj")
("inactive" "interakcyjny")
("include" "wstaw")
("include a document" "wstaw dokument")
("include file" "wstaw plik")
("inclusion into TeXmacs" "wstawnianie do TeXmacs'a")
("inclusions" "wstawki")
("indent" "wcicie")
("indentation flag" "znacznik wcicia")
("index" "indeks")
("index entry" "haso indeksu")
("index level" "poziom indeksu")
("input mode" "tryb wprowadzania")
("insert" "wstaw")
("insert Pr" "wstaw Pr")
("insert a TeXmacs symbol" "wstaw symbol TeXmacsa")
("insert a big operator" "wstaw duy operator")
("insert a binary operation" "wstaw operator dwuarg.")
("insert a binary relation" "wstaw relacj dwuarg.")
("insert a blackboard bold character" "wstaw wytszczony znak pisany")
("insert a bold calligraphic character" "wstaw wytuszczony znak kaligrafowany")
("insert a bold character" "wstaw wytuszczony znak")
("insert a calligraphic character" "wstaw znak kaligrafowany")
("insert a fraction" "wstaw uamek")
("insert a fraktur character" "wstaw znak frakturowy")
("insert a greek character" "wstaw znak grecki")
("insert a large left delimiter" "wstaw duy lewy ogranicznik")
("insert a large right delimiter" "wstaw duy prawy ogranicznik")
("insert a large separator" "wstaw duy separator")
("insert a left subscript" "wstaw lewy indeks dolny")
("insert a link" "wstaw link")
("insert a miscellaneous symbol" "wstaw inny symbol")
("insert a new branch" "wstaw nowy zakres")
("insert a new item" "wstaw nowy element")
("insert a picture" "wstaw obrazek")
("insert a square root" "wstaw pierwiastek kwadratowy")
("insert a table" "wstaw tablic")
("insert a table or a matrix" "wstaw tablic lub macierz")
("insert a wide symbol above" "wstaw szeroki symbol powyej")
("insert a wide symbol below" "wstaw szeroki symbol poniej")
("insert an" "wstaw")
("insert an accent" "wstaw akcent")
("insert an arrow" "wstaw starzak")
("insert an environment" "wstaw nowe rodowisko")
("insert an n" "wstaw n")
("insert appendix" "wstaw dodatek")
("insert arccos" "wstaw arccos")
("insert arcsin" "wstaw arcsin")
("insert arctan" "wstaw arctan")
("insert arg" "wstaw arg")
("insert argument" "wstaw argument")
("insert automatically generated content" "wstaw wygenerowany automatycznie spis")
("insert big contour integral" "wstaw du cak po konturze")
("insert big coproduct" "wstaw duy koprodukt")
("insert big direct sum" "wstaw due sumowanie")
("insert big dotted point" "wstaw duy punkt")
("insert big integral" "wstaw du cak")
("insert big intersection" "wstaw du intersekcj")
("insert big logical and" "wstaw due logiczne i")
("insert big logical or" "wstaw due logiczne lub")
("insert big product" "wstaw duy iloczyn")
("insert big square union" "wstaw du uni kwadratow")
("insert big summation" "wstaw du sum")
("insert big tensor product" "wstaw duy iloczyn tensorowy")
("insert big union" "wstaw du uni")
("insert big union sum" "wstaw du sum zbiorw")
("insert big vertical space" "wstaw duy odstp pionowy")
("insert chapter" "wstaw rozdzia")
("insert column" "wstaw kolumn")
("insert column to the left" "wstaw kolumn po lewej")
("insert column to the right" "wstaw kolumn po prawej")
("insert cos" "wstaw cos")
("insert cosh" "wstaw cosh")
("insert cot" "wstaw cot")
("insert coth" "wstaw coth")
("insert csc" "wstaw csc")
("insert deg" "wstaw deg")
("insert det" "wstaw det")
("insert dim" "wstaw dim")
("insert dollar" "wstaw dolar")
("insert equation" "wstaw rwnanie")
("insert executable markup" "wstaw wykonalny znacznik")
("insert exp" "wstaw exp")
("insert footnote" "wstaw przypis")
("insert formula" "wstaw wzr")
("insert gcd" "wstaw gcd")
("insert hom" "wstaw hom")
("insert horizontal interword space" "wstaw poziomy odstp midzywyrazowy")
("insert image" "wstaw obrazek")
("insert inactive markup" "wstaw nieaktywny znacznik")
("insert inf" "wstaw inf")
("insert ker" "wstaw ker")
("insert lg" "wstaw lg")
("insert lim" "wstaw lim")
("insert liminf" "wstaw liminf")
("insert limsup" "wstaw limsup")
("insert ln" "wstaw ln")
("insert log" "wstaw log")
("insert mathematics" "wstaw matematyk")
("insert max" "wstaw max")
("insert medium horizontal space" "wstaw redni odstp poziomy")
("insert medium vertical space" "wstaw redni odstp pionowy")
("insert min" "wstaw min")
("insert negative horizontal space" "wstaw wsteczny odstp poziomy")
("insert new item or number" "wstaw nowy element lub liczb")
("insert new rows or columns" "wstaw nowe rzdy lub kolumny")
("insert or delete rows or columns" "wstaw lub kasuj rzdy lub kolumny")
("insert row" "wstaw rzd")
("insert row above" "wstaw rzd powyej")
("insert row below" "wstaw rzd poniej")
("insert sec" "wstaw sec")
("insert section" "wstaw akapit")
("insert sharp" "wstaw sharp")
("insert sin" "wstaw sin")
("insert sinh" "wstaw sinh")
("insert small horizontal space" "wstaw may odstp poziomy")
("insert small vertical space" "wstaw may odstp pionowy")
("insert structural markup" "wstaw strukturalny znacznik")
("insert subsection" "wstaw punkt")
("insert subsubsection" "wstaw podpunkt")
("insert sup" "wstaw sup")
("insert tan" "wstaw tan")
("insert tanh" "wstaw tanh")
("insert text field" "wstaw pole tekstowe")
("insert thick horizontal space" "wstaw szeroki odstp poziomy")
("interfacing" "interfacing")
("interfacing TeXmacs with other systems" "interfejs TeXmacs'a z innymi systemami")
("interjection" "w miejsce")
("interline separation" "odlego interlinii")
("interline space" "odstpy midzy liniami")
("internationalization" "umidzynarodowienie")
("interparagraph space" "odstp midzy akapitami")
("interrupt execution" "przerwij wykonanie")
("introduction" "wprowadzenie")
("invisible" "niewidoczny")
("invisible citation" "niewidoczny cytat")
("irish" "irlandzki")
("is running" "praca w toku")
("is tuple" "is tuple")
("ispell does not respond" "ispell nie odpowiada")
("ispell is already busy" "ispell jest zajty")
("italian" "woski")
("italic" "kursywa")
("italic right" "kursywa w prawo")
("itemize" "wyszczeglnienie")
("january" "stycze")
("japanese" "japoski")
("july" "lipiec")
("june" "czerwiec")
("justified" "wyrwnany")
("justify text" "wyrwnuj tekst")
("key" "klawisz")
("keyboard" "klawiatura")
("keyboard equivalent" "skrt klawiszowy")
("keyboard modifiers" "modyfikatory klawiatury")
("keyboard shortcut" "skrt klawiszowy")
("keymaps" "mapa klawiszy")
("keyword" "sowo kluczowe")
("keywords" "sowa kluczowe")
("kill" "zniszcz")
("known bugs" "znane problemy")
("label" "etykieta")
("landscape" "poprzecznie")
("language" "jzyk")
("large" "wielki")
("large closing bracket" "duy zamykajcy nawias")
("large delimiter" "duy ogranicznik")
("large opening bracket" "duy otwierajcy nawias")
("large separator" "duy separator")
("last page" "ostatnia strona")
("latex command" "komenda latex")
("latin" "aciski")
("layout" "ukad")
("left" "w lewo")
("left arrow" "strzaka w lewo")
("left border" "lewy brzeg")
("left margin" "lewy margines")
("left padding" "lewe wypenienie")
("left prime" "lewy prime")
("left aligned" "wyrwnanie do lewej")
("left slanted" "pochylony w lewo")
("left subscript" "lewy indeks dolny")
("left superscript" "lewy indeks grny")
("left surrounding" "lewe otoczenie")
("legal" "legal")
("lemma" "lemat")
("length" "dugo")
("less" "mniejszy")
("less or equal" "mniejszy lub rwnu")
("letter" "list")
("license" "licencja")
("light" "jasny")
("light grey" "jasno-szary")
("limitations" "ograniczenia")
("limits" "granice")
("line" "linia")
("line break" "koniec linii")
("line stretch" "rozpicie linii")
("link" "link")
("link image" "link do obrazka")
("list" "lista")
("list of figures" "spis ryskunkw")
("list of tables" "spis tablic")
("load" "aduj")
("load LaTeX file" "aduj plik formatu LaTeX")
("load TeX file" "aduj plik formatu TeX")
("load TeXmacs file" "aduj plik TeXmacs")
("load TeXmacs style file" "aduj plik style")
("load a file" "aduj plik")
("load buffer" "aduj bufor")
("load file" "aduj plik")
("load html file" "aduj plik html")
("load image" "aduj obrazek")
("load in new window" "aduj do nowego okna")
("load latex file" "duj plik latex")
("load more recent autosave file" "aduj najnowsze pliki autosave")
("load tex file" "aduj plik tex")
("load verbatim file" "aduj plik verbatim")
("loaded" "zaadowany")
("long" "dugi")
("look and feel" "wygld")
("look up" "zajrzyj")
("lower border" "dolny brzeg")
("m modifier" "m modyfikator")
("macro" "makro")
("magenta" "fioletowy")
("magic" "magic")
("magnification" "powikszenie")
("magnified" "powikszony")
("main" "gwne")
("main icon bar" "gwny pasek ikon")
("major changes" "gwne zmiany")
("make a page insertion" "zrb wstawnienie strony")
("make a subscript" "utwrz indeks dolny")
("make a superscript" "utwrz indeks grny")
("make acute" "utwrz acute")
("make bar" "utwrz kresk")
("make check" "utwrz haczyk")
("make fraction" "utwrz uamek")
("make grave" "utwrz grave")
("make hat" "utwrz daszek")
("make label" "utwrz etykiet")
("make negation" "utwrz negacj")
("make page reference" "zrb odnonik do strony")
("make reference" "utwrz odsyacz")
("make square root" "utwrz pierwiastek kwadratowy")
("make tilde" "utwrz tyld")
("make title" "zrb tytu")
("make vector" "utwrz wektor")
("making donations" "robienie donations")
("manual" "podrcznik")
("map to" "zmie na")
("march" "marzec")
("margins" "marginesy")
("margins as on paper" "marginesy jak na papierze")
("master" "gwny")
("master file" "gwny plik")
("math" "matma")
("math font" "czcionka matematyczna")
("math font family" "czcionka mat. rodzina")
("math font series" "czcionka mat. seria")
("math font shape" "czcionka mat. ksztat")
("mathematical" "matematyczny")
("mathematical formulas" "formuy matematyczne")
("mathematical typesetting" "typesetting matematyczny")
("mathematics" "matematyka")
("matrix" "macierz")
("maximal number of columns" "maksymalna liczba kolumn")
("maximal number of rows" "maksymalna liczba rzdw")
("maximum mode" "tryb maksimum")
("may" "maj")
("medium" "redni")
("medium skip" "redni odstp")
("meminfo" "pami")
("merge" "rozszerzenie")
("messy" "messy")
("meta key" "klawisz meta")
("middle" "na rodek")
("minimal number of columns" "minimalna liczba kolumn")
("minimal number of rows" "minimalna liczba rzdw")
("minimum mode" "tryb minimum")
("minus" "minus")
("miscellaneous" "rne")
("miscellaneous features" "rne funkcje")
("mod" "modulo")
("mode" "tryb")
("modifier" "modyfikator")
("modify cell alignment" "zmie wyrwnanie komrki")
("modify cell border" "zmie ramk komrki")
("modify cell padding" "zmie wypenienie komrki")
("modify cell size" "zmie rozmiar komrki")
("modify table border" "zmie ramk tablicy")
("modify table padding" "zmie wypenienie tablicy")
("mongolian" "mongolski")
("more information about GNU TeXmacs can be found in the help" "wicej informacji na temat GNU TEXmacs'a mona znale w Pomocy")
("mosaic" "mosaic")
("move down" "przesu w d")
("move object" "przesu obiekt")
("move to the right when finished" "przesu na prawo po skoczeniu")
("move up" "przesu w gr")
("my documents" "moje dokumenty")
("n-th" "-ty/a")
("n-th root" "pierwiastek n-ty")
("name" "nazwa")
("negation" "negacja")
("new" "nowy")
("new buffer" "nowy bufor")
("new column" "nowa kolumna")
("new item" "nowy element")
("new line" "nowa linia")
("new number" "nowa warto")
("new page" "nowa strona")
("new page before" "nowa strona przed")
("new paragraph" "nowy akapit")
("new roman" "new roman")
("new row" "nowy rzd")
("new table" "nowa tablica")
("next line" "nastpna linia")
("no changes need to be saved" "nie trzeba zapisywa")
("no dictionary for" "brak sownika dla")
("no first indentation" "bez pierwszego wcicia")
("no indentation" "bez wci")
("no line break" "bez amania linii")
("no matches found" "nie znaleziono dopasowa")
("no matches found for" "nie znaleziono dopasowa dla")
("no more matches for" "brak dopasowa dla")
("no more redo information available" "brak informacji redo")
("no more undo information available" "brak informacji undo")
("no name" "bez nazwy")
("no page break after" "bez amania strony po")
("no page break before" "bez amania strony przed")
("no spelling errors found in text" "brak bdw pisowni")
("no style" "brak styli")
("none" "aden")
("normal" "normalny")
("norwegian" "norweski")
("not" "nie")
("not equal" "nie rwny")
("not found" "nie znaleziono")
("notation" "notacja")
("note" "notka")
("november" "listopad")
("number" "liczba")
("number equation" "numerowane rwnanie")
("number of columns" "liczba kolumn")
("numbered equation" "numerowane rwnanie")
("numbered equations" "numerowane rwnania")
("numerator" "licznik")
("numeric" "numeryczny")
("objectives" "objectives")
("occurrences" "wystpie/nia")
("october" "padziernik")
("odd page footer" "nieparzysty")
("odd page header" "nieparzysty nagwek strony")
("odd page margin" "nieparzyste marginesy strony")
("odd page text" "tekst na stronach nieparzystych")
("off" "wycz")
("ok" "ok")
("old english" "staro-angielski")
("old slavonic" "starp-sowiaski")
("old style" "dawny styl")
("on" "wcz")
("on cells" "na komrkach")
("on columns" "na kolumnach")
("on entire table" "na caej tablicy")
("on rows" "na rzdach")
("one spelling error has been corrected" "poprawiono jeden bd pisowni")
("online documentation" "dokumentacja on line")
("online help" "pomoc on line")
("open" "otwrz")
("open a new buffer" "otwrz nowy bufor")
("open new window" "otwrz nowe okno")
("opening" "otwarcie")
("operation on named selection" "operacja na nazwanych selekcjach")
("operation on primary selection" "oparacja na pierwszej selekcji")
("operation on secondary selection" "operacja na drugiej selekcji")
("operation on ternary selection" "opreacja na trzeciej selekcji")
("optical" "optical")
("option" "opcja")
("options" "opcje")
("or" "lub")
("orange" "pomaraczowy")
("orientation" "uoenie")
("origin" "pochodzenie")
("original welcome message" "oryginalna wiadomo powitania")
("other" "inne")
("other pages" "inne strony")
("other projects" "inne projekty")
("other style" "inny styl")
("outlined roman" "outlined roman")
("over" "przez")
("overbrace" "klamra grna")
("overline" "kreska grna")
("padding" "wypenienie")
("page" "strona")
("page bottom margin" "dolny margines strony")
("page break" "zakocz stron")
("page break before" "koniec strony przed")
("page height" "wysoko strony")
("page insertion" "wstawianie na stronie")
("page layout" "ukad strony")
("page number text" "tekst numeracji strony")
("page numbering" "numeracja stron")
("page reference" "odsyacz do strony")
("page right margin" "prawy margines strony")
("page setup" "ustawienia strony")
("page top margin" "grny margines strony")
("page type" "typ strony")
("page width" "szeroko strony")
("paper" "papier")
("paper type" "rodzaj papieru")
("papyrus" "papirus")
("paragraph" "akapit")
("paragraph mode" "tryb akapitu")
("paragraph width" "szeroko akapitu")
("part" "cz")
("past changes" "ostatnie zmiany")
("paste" "wklej")
("paste from" "wklej z")
("paste text" "wklej tekst")
("path" "cieka")
("perform operations on cells" "wykonaj operacje na komrkach")
("perform operations on columns" "wykonaj operacje na kolumnach")
("perform operations on entire table" "wykonaj operacje na caej tablicy")
("perform operations on rows" "wykonaj operaje na rzdach")
("permanent" "stay")
("person" "osoba")
("personal dictionary has been modified" "zmieniony sownik osobisyty")
("phantasy" "phantasy")
("philosophy" "filozofia")
("phoenician" "phoenician")
("phonetic" "phonetic")
("pink" "rowy")
("plain block" "zwyky blok")
("plain tabular" "zwyke tabulowanie")
("planned changes" "planowane zmiany")
("plans for the future" "plany na przyszo")
("please" "prosz")
("please wait" "prosz czeka")
("plugin" "wtyczka")
("plugins" "wtyczki")
("plus" "plus")
("polish" "polski")
("porting TeXmacs to other platforms" "przeniesienie TeXmacs'a na inne platformy")
("portrait" "pionowo")
("portuguese" "portugalski")
("position" "pozycja")
("position float" "pozycja pynna")
("position floating object" "pozycja pynnego obiektu")
("position the table" "pozycja tablicy")
("postscript" "postscript")
("postscript image" "obrazek postscriptowy")
("pre-alpha release" "wydanie pre-alpha")
("preamble" "kody jawne")
("preamble mode" "tryb preambuy")
("preferences" "ustawienia")
("presentation" "prezentacja")
("presentation mode" "tryb prezentacji")
("presentation tag" "znacznik prezentacji")
("preview before printing" "podgld przed wydrukiem")
("preview command" "polecenie podgldu")
("preview with ghostview" "podgld przez ghostview")
("primary" "pierwszego")
("prime" "prime")
("print" "drukuj")
("print all" "drukuj wszystko")
("print all to file" "drukuj wszystko do pliku")
("print page selection" "drukuj wybrane strony")
("print page selection to file" "drukuj wybrane strony do pliku")
("print to postscript file" "drukuj do pliku postscriptowego")
("printer" "drukarka")
("printer dpi" "dpi drukarki")
("printing command" "parametr wydruku")
("problem" "problem")
("professional" "profesjonalny")
("prog" "program")
("prog font" "czcionka programowa")
("prog font family" "czcionka prog. rodzina")
("prog font series" "czcionka prog. seria")
("prog font shape" "czcionka prog. ksztat")
("program" "program")
("program mode" "tryb programu")
("programming" "programowanie")
("progressive" "progresywny")
("project" "projekt")
("projects" "projekty")
("prologue" "kody jawne")
("prompt on scripts" "potwierd skrypt")
("proof" "dowd")
("proportional" "proporcjonalny")
("proportional typewriter" "proporcjonalny maszynowy")
("proposition" "stwierdzenie")
("query replace" "zamieniaj")
("quit" "zakocz")
("quotation" "cytowane")
("quote" "cytat")
("range" "zakres")
("really close it" "na pewno chcesz zamkn")
("really huge" "przeogromny")
("really quit" "rzeczywicie zakoczy")
("red" "czerwony")
("redo" "przywoaj ponownie operacj")
("redo undone changes" "przywoaj ostatnio wycofan zmian")
("reduce bottom margin by" "zredukuj dolny margines o")
("reduce left margin by" "zredukuj lewy margines o")
("reduce margins" "zredukuj marginesy")
("reduce right margin by" "zredukuj prawy margines o")
("reduce top margin by" "zredukuj grny margines o")
("reduction even page margin" "redukcja nieparzystego marginesu strony")
("reduction odd page margin" "redukcja parzystego margiesu strony")
("reduction page bottom margin" "redukcja dolnego marginesu strony")
("reduction page right margin" "redukcja prawego marginesu strony")
("reduction page top margin" "redukcja grnego marginesu strony")
("reference" "odsyacz")
("references" "odsyacze")
("regular" "zwyke")
("release" "wydanie")
("reload" "przeaduj")
("remark" "uwaga")
("remove number" "usu numer")
("remove this switch" "usu ten przecznik")
("renumber this page" "zmie numeracj tej strony")
("repeat object" "powtrz obiekt")
("replace" "zamie")
("replace by" "zamie na")
("replaced" "zamieniono")
("replaced one occurrence" "zamieniono pojedyncze wystpienie")
("reset" "skasuj")
("resize object" "przeskaluj obiekt")
("resized" "przeskalowany")
("search results for" "wyniki wyszukiwania dla")
("return" "powrt")
("revert" "przywr")
("revert buffer" "przywr bufor")
("right" "w prawo")
("right arrow" "strzaka w prawo")
("right border" "prawy brzeg")
("right margin" "prawy margines")
("right padding" "prawe wypenienie")
("right aligned" "wyrwnanie do prawej")
("right subscript" "prawy indeks dolny")
("right superscript" "prawy indeks grny")
("right surrounding" "prawe otoczenie")
("rigid" "twardy")
("rigid horizontal" "twardy poziom")
("rigid space" "twardy odstp")
("romanian" "rumuski")
("root" "pierwiastek")
("rotate backward" "odwr w ty")
("rotate forward" "odwr w przd")
("row" "rzd")
("row contains glued items" "rzd zawiera elementy sklejone")
("runic" "runic")
("running author" "przewodni autor")
("running title" "przewodni tytlu")
("russian" "rosyjski")
("sample" "prba")
("sans serif" "sans serif")
("save" "zapisz")
("save TeXmacs file" "zapisz plik TeXmacs")
("save TeXmacs style file" "zapisz plik styli TeXmacs")
("save as" "zapisz jako")
("save as LaTeX" "zapisz w formacie LaTeX")
("save as TeX" "zapisz w formacie TeX")
("save buffer" "zapisz bufor")
("save buffer as" "zapisz bufor jako")
("save file" "zapisz plik")
("save html file" "zapisz plik html")
("save image" "zapisz obrazek")
("save latex file" "zapisz plik latex")
("save tex file" "zapisz plik tex")
("save this buffer" "zapisz ten bufor")
("save verbatim file" "zapisz plik verbatim")
("saved" "zapisano")
("screen layout" "ustawienie ekranu")
("screen margins" "marginesy ekranu")
("script" "skrypt")
("script above" "pisane powyej")
("script below" "pisane poniej")
("script script size" "rozmiar script script")
("script size" "rozmiar script")
("scripts not accepted" "skryptu nie zaakceptowano")
("search" "szukaj")
("search words in my documents" "wyszukiwanie sw we wasnych dokumentach")
("search words in the documentation" "wyszukiwanie sw w dokumentacji")
("search words in the source code" "wyszukiwanie sw w kodzie rdowym")
("searching" "poszukiwanie")
("secondary" "drugiego")
("section" "akapit")
("security" "bezpieczestwo")
("see" "zobacz")
("select a document style" "wybierz styl dokumentu")
("select a foreground color" "wybierz kolor pisma")
("select a language" "wybierz jzyk")
("selected region" "obszar zaznaczony")
("selection" "selekcja")
("selections" "wybory")
("seminar" "seminarium")
("sending commands to TeXmacs" "wysyanie komend do TeXmacs'a")
("separation between lines" "separacja midzy liniami")
("separation between paragraphs" "separacja midzy akapitami")
("separator" "separator")
("september" "wrzesie")
("serb" "serbski")
("series" "seria")
("series|right" "seria|prawy")
("session" "sesja")
("session name" "nazwa sesji")
("session type" "typ sesji")
("sessions" "sesje")
("set" "ustaw")
("set background color of cell" "ustaw kolor ta komrki")
("set cell mode" "ustaw tryb komrki")
("set extension center" "ustaw rodek poszerzenia")
("set height" "ustaw wysoko")
("set height of cell" "ustaw wysoko komrki")
("set margins" "ustawienie marginesw")
("set n" "ustaw n")
("set paragraph margins" "ustaw marginesy akapitu")
("set paragraph mode" "ustaw form akapitu")
("set printer dpi" "ustaw dpi drukarki")
("set printing command" "ustaw parametry wydruku")
("set span" "ustaw rozpito")
("set special cell properties" "ustaw specjalne waciwoci komrki")
("set special table properties" "ustaw specjalne waciwoci tablicy")
("set text width" "ustaw szeroko tekstu")
("set width" "ustaw szeroko")
("set width of cell" "ustaw szeroko komrki")
("settings" "ustawienia")
("setup printer" "ustaw drukark")
("shape" "ksztat")
("shift-down" "przesu w d")
("shift-right" "przesu w prawo")
("show" "poka")
("show header and footer" "poka nagwek i stopk")
("show on screen" "poka na ekranie")
("shrinking factor" "czynnik zwenia")
("signature" "podpis")
("size" "rozmiar")
("size limits" "granice rozmiaru")
("slanted" "pochylony")
("sloppy" "byle jaki")
("small" "may")
("small caps" "may")
("small figure" "may obrazek")
("small skip" "may odstp")
("small table" "maa tablica")
("source code" "kod rdowy")
("space" "odstp")
("space between lines" "odstp midzy liniami")
("space between paragraphs" "odstp midzy paragrafami")
("spacing" "odstpy")
("spanish" "hiszpaski")
("special" "specjalne")
("special cell properties" "specjalne waciwoci komrki")
("special table properties" "specjalne waciwoci tablicy")
("specific" "specyficzny")
("spell" "pisownia")
("spell checking complete" "koniec sprawdzania pisowni")
("spelling error" "bd pisowni")
("spelling errors have been corrected" "bdy pisowni zostay poprawione")
("split" "podziel")
("split session" "podziel sesj")
("square root" "pierwiastek kwadratowy")
("start" "start")
("start a new chapter" "rozpocznij nowy rozdzia")
("start a new section" "rozpocznij nowy akapit")
("start an interactive session" "rozpocznij sesj interaktywnie")
("status bar" "pasek stanu")
("stretchable" "rozpicie")
("stretchable horizontal" "rozpicie w poziomie")
("stretchable vertical" "rozpicie w pionie")
("stroke" "przekrel")
("strokes" "przekrelenia")
("strong" "mocny")
("structural" "strukturalny")
("style" "styl")
("styles" "style")
("sub" "podrzdne")
("subparagraph" "pod-paragraf")
("subscript" "indeks dolny")
("subsection" "punkt")
("subsub" "pod-podrzdne")
("subsubsection" "podpunkt")
("summary" "streszczenie")
("summary of the principal TeXmacs tags" "informacje o podstawowych znacznikach TeXmacs'a")
("superpose" "superpoza")
("superposed" "superpozowany")
("superscript" "indeks grny")
("swedish" "szwedzki")
("switch" "przecznik")
("switch to first" "przecz na pierwszy")
("switch to formula style" "przecz na styl rwna")
("switch to last" "przecz na ostatni")
("switch to next" "przecz na nastpny")
("switch to previous" "przecz na poprzedni")
("switching and folding" "przeczanie i foldowanie")
("symbol" "symbol")
("system environment variables" "zmienne otoczenia systemu")
("tab" "tab")
("table" "tablica")
("table command" "rozkaz tablicy")
("table of contents" "spis treci")
("tables" "tablice")
("tabular" "tabulowanie")
("tabular material" "materia tabulowany")
("teXmacs as an interface" "teXmacs jako interfejs")
("teXmacs fonts" "czcionki TeXmacs'a")
("teXmacs notice" "noty TeXmacs'a")
("teXmacs plugins" "wtyczki TeXmacs'a")
("teXmacs style files" "pliki stylw teXmacs")
("ternary" "trzeciego")
("test" "test")
("tex" "tex")
("text" "tekst")
("text font" "czcionka tekstowa")
("text height correction" "poprawa wysokoci tekstu")
("text width" "szeroko tekstu")
("texts" "teksty")
("th century bc" "th century bc")
("th root" "-ty pierwiastek")
("thai" "thai")
("the TeXmacs authors" "autorzy TeXmacs'a")
("the application did not send its usual startup banner" "aplikacja nie przesaa swego startowego bannera")
("the application does not reply" "aplikacja nie odpowiada")
("the application is already running" "aplikacja ju uruchomiona")
("the boxes produced by the typesetter" "pudeko wykonane przez zecera")
("the graphical user interface" "interfejs graficzny uytkownika")
("the leaves of TeXmacs trees" "licie drzew TeXmacs'a")
("the mycas example" "przykad mycas")
("the primitive TeXmacs constructs" "podstawowe konstrukty TeXmacs'a")
("the standard TeXmacs styles" "standardowe style TeXmacs'a")
("theorem" "twierdzenie")
("there are unsaved files" "s niezapisane pliki")
("this buffer has not been saved" "ten bufor nie by zapisywany")
("this document has been produced using" "ten dokument by wykonany przy uyciu")
("this line" "ta linia")
("this page" "ta strona")
("tilda" "tylda")
("tilde" "tylde")
("times" "razy")
("tiny" "maleki")
("title" "tytu")
("to the left" "do lewej")
("to the right" "do prawej")
("today" "dzisiaj")
("tools" "narzdzia")
("top" "na pocztek")
("top border" "grna ramka")
("top level" "poziom grny")
("top margin" "grny margines")
("top padding" "grne wypenienie")
("translate" "transliteracja")
("tree" "drzewo")
("tuple" "tuple")
("turkish" "turecki")
("tutorial" "podrcznik")
("type" "typ")
("type a latex command followed by" "wpisz komend latex a nastpnie")
("type body" "wpisz zawarto")
("type denominator" "wpisz mianownik")
("type numerator" "licznik typu")
("type script" "wpisz skrypt")
("typesetted boxes" "pudeka zecera")
("typewriter" "maszynowy")
("typewriter small caps" "may maszynowy")
("typing a simple text" "pisanie prostego tekstu")
("typing simple texts" "pisanie prostych tekstw")
("ugaritic" "ugaritic")
("ukrainian" "ukraiski")
("underbrace" "klamra dolna")
("underline" "podkrelenie")
("undo" "cofnij operacj")
("undo last changes" "wycofaj ostatni zmian")
("up" "do gry")
("update" "aktualizuj")
("update from web" "update z web")
("update image links" "update linki obrazkw")
("upper border" "grny brzeg")
("use TeXmacs" "uyj TeXmacs'a")
("use a black color" "uyj koloru czarnego")
("use a blue color" "uyj koloru niebieskiego")
("use a bold font" "uyj tustej czcionki")
("use a brown color" "uyj koloru brzowego")
("use a calligraphic font" "uyj czcionki kaligraficznej")
("use a green color" "uyj koloru zielonego")
("use a grey color" "uyj koloru szarego")
("use a magenta color" "uyj koloru fioletowego")
("use a orange color" "uyj koloru pomaraczowego")
("use a pink color" "uyj koloru rowego")
("use a red color" "uyj koloru czerwonego")
("use a sans serif font" "uyj czcionki sans serif")
("use a typewriter font" "uyj czcionki maszynowej")
("use a white color" "uyj koloru biaego")
("use a yellow color" "uyj koloru tego")
("use blackboard bold font" "uyj czcionek blackboard")
("use bold font series" "uuj czcionek tustych")
("use calligraphical font" "uyj czcionek kaligraficznych")
("use footnote font size" "uyj czcionek rozmiaru przypisw")
("use fraktur font" "uyj czcionek fraktury")
("use huge font size" "uyj czcionek rozmiaru ogromnego")
("use italic font shape" "uyj czcionek italic shape")
("use large font size" "uyj czcionek rozmiaru duego")
("use left hand column as border" "uyj lewej kolumny jako ramki")
("use medium font series" "uyj czcionek medium")
("use normal font size" "uyj czcionek rozmiaru normalnego")
("use package" "uyj pakietu")
("use paragraph width" "uyj szerokoci paragrafu")
("use really huge font size" "uyj czcionek rozmiaru przeogromnego")
("use right font shape" "uyj czcionek right shape")
("use right hand column as border" "uyj prawej kolumny jako ramki")
("use roman font family" "uyj czcionek rzymskich")
("use row above as border" "uyj rzdu powyej jako ramki")
("use row below as border" "uyj rzdu poniej jako ramki")
("use sans serif font family" "uyj czcionek sans serif")
("use script font size" "uyj czcionek script")
("use slanted font shape" "uyj czcionek slanded shape")
("use small capitals" "uyj czcionki small capitals")
("use small font size" "uyj czcionek rozmiaru maego")
("use small-caps font shape" "uyj czcionek small-caps shape")
("use the blackboard bold font" "uyj cicionki blackboard")
("use the fraktur font" "uyj czcionki fraktur")
("use tiny font font size" "uyj czcionek malekich")
("use typewriter font family" "uyj czcionek maszynowych")
("use very large font size" "uyj czcionek rozmiaru bardzo duego")
("user manual" "podrcznik uytkownika")
("user provided icons" "ikony uytkownika")
("users of Cyrillic languages" "uytkownicy Cyrlicy ")
("value" "warto")
("variable" "zmienna")
("variant" "wariant")
("vector" "wektor")
("verbatim" "dosownie")
("verse" "werset")
("vertical" "pionowo")
("vertical after" "w pionie po")
("vertical before" "w pionie przed")
("vertical cell alignment" "wyrwnanie pionowe komrki")
("vertical part" "pionowa cz")
("vertical position" "pooenie poziome")
("vertical space" "odstp pionowy")
("vertical table alignment" "wyrwnanie pionowe tablicy")
("vertically align cell to the base" "wyrwnaj pionowo komrk do bazy")
("vertically center the cell" "wycentruj pionowo komrk")
("very large" "bardzo wielki")
("very small" "bardzo may")
("vietnamese" "wietnamski")
("view" "widok")
("visible" "widoczny")
("warning" "ostrzeenie")
("welcome" "powitanie")
("welcome to GNU TeXmacs" "Witaj w GNU TeXmacs")
("what is new" "co nowego")
("when finished" "kiedy skoczone")
("while" "dopki")
("white" "biay")
("wide accent" "szeroki akcent")
("wide bar" "szeroka kreska")
("width" "szeroko")
("width is exactly the specified width" "szeroko jest dokadnie podana")
("width is maximum of specified width and box width" "szeroko jest maximum z podanej i szerokoci pudeka")
("width is minimum of specified width and box width" "szeroko jest minimum z podanej i szerokoci pudeka")
("width magnification" "zwikszenie w poziomie")
("window" "okno")
("window height" "wysoko okna")
("window width" "szeroko okna")
("windows key" "klawisz okna")
("with" "z")
("write a name" "wpisz nazwisko")
("write bold mathematics" "pisz na tusto matematyk")
("write bold text" "pisz tekst na tusto")
("write italic text" "pisz tekst kursyw")
("write sample text" "wpisz prosty tekst")
("write strong text" "wpisz tusty tekst")
("write typewriter text" "wpisz maszynowy tekst")
("write verbatim text" "wpisz vervatim tekst")
("writing data converters" "zapis konwerterw danych")
("writing your own style files" "zapis wasnych plikw styli")
("yellow" "ty")
("you can also obtain" "mona otrzyma take")
("your document is back in its original state" "dokument jest na nowo w stanie pierwotnym")
("your first interface" "twj pierwszy interface")
("your language" "twj jzyk")
